==> manaplus_1.6.5.7.orig.tar.xz: manaplus-1.6.5.7/src/net/eathena/maprecv.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2016  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/eathena/maprecv.h"

#include "gui/viewport.h"

#include "net/messagein.h"

#include "resources/map/map.h"

#include "debug.h"

namespace EAthena
{

void MapRecv::processInstanceStart(Net::MessageIn &msg)
{
    UNIMPLIMENTEDPACKET;
    msg.readString(61, "instance name");
    msg.readInt16("flag");
}

void MapRecv::processInstanceCreate(Net::MessageIn &msg)
{
    UNIMPLIMENTEDPACKET;
    msg.readInt16("flag");
}

void MapRecv::processInstanceInfo(Net::MessageIn &msg)
{
    UNIMPLIMENTEDPACKET;
    msg.readString(61, "instance name");
    msg.readInt32("remaining time");
    msg.readInt32("no players close time");
}

void MapRecv::processInstanceDelete(Net::MessageIn &msg)
{
    UNIMPLIMENTEDPACKET;
    msg.readInt32("flag");
    msg.readInt32("unused");
}

void MapRecv::processSetTilesType(Net::MessageIn &msg)
{
    const int x1 = msg.readInt16("x1");
    const int y1 = msg.readInt16("y1");
    const int x2 = msg.readInt16("x2");
    const int y2 = msg.readInt16("y2");
    const BlockTypeT mask = static_cast<BlockTypeT>(msg.readInt32("mask"));
    const int layer = msg.readInt32("layer");
    const std::string name = msg.readString(16, "map name");
    if (layer)
        return;
    Map *const map = viewport->getMap();
    if (map && map->getGatName() == name)
    {
        for (int y = y1; y <= y2; y ++)
        {
            for (int x = x1; x <= x2; x ++)
                map->setBlockMask(x, y, mask);
        }
        map->updateConditionLayers();
    }
}

}  // namespace EAthena

==> manaplus_1.6.12.24.orig.tar.xz: manaplus-1.6.12.24/src/net/eathena/maprecv.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2016  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/eathena/maprecv.h"

#include "logger.h"

#include "net/messagein.h"

#include "debug.h"

namespace EAthena
{

void MapRecv::processInstanceStart(Net::MessageIn &msg)
{
    UNIMPLEMENTEDPACKET;
    msg.readString(61, "instance name");
    msg.readInt16("flag");
}

void MapRecv::processInstanceCreate(Net::MessageIn &msg)
{
    UNIMPLEMENTEDPACKET;
    msg.readInt16("flag");
}

void MapRecv::processInstanceInfo(Net::MessageIn &msg)
{
    UNIMPLEMENTEDPACKET;
    msg.readString(61, "instance name");
    msg.readInt32("remaining time");
    msg.readInt32("no players close time");
}

void MapRecv::processInstanceDelete(Net::MessageIn &msg)
{
    UNIMPLEMENTEDPACKET;
    msg.readInt32("flag");
    msg.readInt32("unused");
}

void MapRecv::processAddMapMarker(Net::MessageIn &msg)
{
    UNIMPLEMENTEDPACKET;
    msg.readBeingId("account id");
    msg.readInt16("x");
    msg.readInt16("y");
}

}  // namespace EAthena
